==> policy-management-domain-0.2.66-sources.jar: com/xforceplus/ultraman/app/policymanagement/dict/BillChangeRecordSource.java <==
package com.xforceplus.ultraman.app.policymanagement.dict;

import com.baomidou.mybatisplus.annotation.EnumValue;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * <p>
 * bill_change_record_source
 * </p>
 *
 * @author ultraman
 * @since 2024-11-21
 */
public enum BillChangeRecordSource {

    _10("10", "天猫订单"),
    S_PDD("S-PDD", "拼多多销售订单"),
    A_PDD("A-PDD", "拼多多售后"),
    S_TM("S-TM", "天猫销售订单"),
    A_TM("A-TM", "天猫售后"),
    S_KS("S-KS", "快手销售订单"),
    A_KS("A-KS", "快手售后"),
    S_DY("S-DY", "抖音销售订单"),
    A_DY("A-DY", "抖音销售订单"),
    S_JD("S-JD", "京东-销售"),
    A_JD("A-JD", "京东-售后"),
    S_WDGJ("S-WDGJ", "网点管家销售"),
    A_WDGJ("A-WDGJ", "网点管家售后");

    @EnumValue
    @JsonValue
    private final String code;

    private final String desc;

    public String getCode(){
        return this.code;
    }

    public String getDesc(){
        return this.desc;
    }

    BillChangeRecordSource(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }

    @Override
    public String toString() {
        return this.code;
    }

    public static BillChangeRecordSource fromCode(String code){
        switch(code) {
            case "10":
                return _10;
            case "S-PDD":
                return S_PDD;
            case "A-PDD":
                return A_PDD;
            case "S-TM":
                return S_TM;
            case "A-TM":
                return A_TM;
            case "S-KS":
                return S_KS;
            case "A-KS":
                return A_KS;
            case "S-DY":
                return S_DY;
            case "A-DY":
                return A_DY;
            case "S-JD":
                return S_JD;
            case "A-JD":
                return A_JD;
            case "S-WDGJ":
                return S_WDGJ;
            case "A-WDGJ":
                return A_WDGJ;
            default:
                return null;
        }
    }
}

==> policy-management-domain-0.3.5-sources.jar: com/xforceplus/ultraman/app/policymanagement/dict/BillChangeRecordSource.java <==
package com.xforceplus.ultraman.app.policymanagement.dict;

import com.baomidou.mybatisplus.annotation.EnumValue;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * <p>
 * bill_change_record_source
 * </p>
 *
 * @author ultraman
 * @since 2024-11-25
 */
public enum BillChangeRecordSource {

    S_PDD("S-PDD", "拼多多销售订单"),
    A_PDD("A-PDD", "拼多多售后"),
    S_TM("S-TM", "天猫销售订单"),
    A_TM("A-TM", "天猫售后"),
    S_KS("S-KS", "快手销售订单"),
    A_KS("A-KS", "快手售后"),
    S_DY("S-DY", "抖音销售订单"),
    A_DY("A-DY", "抖音销售订单"),
    S_JD("S-JD", "京东-销售"),
    A_JD("A-JD", "京东-售后"),
    S_WDGJ("S-WDGJ", "网点管家销售"),
    A_WDGJ("A-WDGJ", "网点管家售后"),
    DEFAULT("default", "默认");

    @EnumValue
    @JsonValue
    private final String code;

    private final String desc;

    public String getCode(){
        return this.code;
    }

    public String getDesc(){
        return this.desc;
    }

    BillChangeRecordSource(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }

    @Override
    public String toString() {
        return this.code;
    }

    public static BillChangeRecordSource fromCode(String code){
        switch(code) {
            case "S-PDD":
                return S_PDD;
            case "A-PDD":
                return A_PDD;
            case "S-TM":
                return S_TM;
            case "A-TM":
                return A_TM;
            case "S-KS":
                return S_KS;
            case "A-KS":
                return A_KS;
            case "S-DY":
                return S_DY;
            case "A-DY":
                return A_DY;
            case "S-JD":
                return S_JD;
            case "A-JD":
                return A_JD;
            case "S-WDGJ":
                return S_WDGJ;
            case "A-WDGJ":
                return A_WDGJ;
            case "default":
                return DEFAULT;
            default:
                return null;
        }
    }
}
